registerWith static method
void
registerWith()
Registers this class as the default instance of PathProviderPlatform.
Implementation
static void registerWith() {
VideoPlayerPlatform.instance = AndroidVideoPlayer();
}
Registers this class as the default instance of PathProviderPlatform.
static void registerWith() {
VideoPlayerPlatform.instance = AndroidVideoPlayer();
}